//
//  setSubId.java
//  Leadbolt Plugin
//
//  Copyright (c) 2014 Gremlin Interactive™. All rights reserved.
//

// Package name
package plugin.leadbolt;

// Android Imports
import android.content.Context;
import android.os.Environment;

// JNLua imports
import com.naef.jnlua.LuaState;
import com.naef.jnlua.LuaType;

// Corona Imports
import com.ansca.corona.CoronaActivity;
import com.ansca.corona.CoronaEnvironment;
import com.ansca.corona.CoronaLua;
import com.ansca.corona.CoronaRuntime;
import com.ansca.corona.CoronaRuntimeTask;
import com.ansca.corona.CoronaRuntimeTaskDispatcher;
import com.ansca.corona.storage.FileContentProvider;

// Java/Misc Imports
import java.math.BigDecimal;
import org.json.JSONException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.List;
import java.io.File;
import java.lang.Object;
import java.io.OutputStreamWriter;
import java.io.IOException;
import java.io.FileNotFoundException;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.InputStream;
import java.io.FileOutputStream;
import java.io.FileReader;

// Android Imports
import android.app.Activity;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.util.Log;
import android.content.ContentProvider;
import android.content.ContentUris;
import android.content.ContentValues;
import android.content.Context;
import android.content.UriMatcher;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.graphics.drawable.Drawable;
import android.widget.ImageView;
import android.R;
import android.R.drawable;

// Leadbolt imports
import com.appfireworks.android.listener.AppModuleListener;
import com.appfireworks.android.track.AppTracker;
import com.uhoqlixqyrntlnty.AdController;

/**
 * Implements the setSubId() function in Lua.
 * <p>
 * 
 */
public class setSubId implements com.naef.jnlua.NamedJavaFunction 
{
    /**
     * Gets the name of the Lua function as it would appear in the Lua script.
     * @return Returns the name of the custom Lua function.
     */
    @Override
    public String getName()
    {
        return "setSubId";
    }

    /**
     * This method is called when the Lua function is called.
     * <p>
     * Warning! This method is not called on the main UI thread.
     * @param luaState Reference to the Lua state.
     *                 Needed to retrieve the Lua function's parameters and to return values back to Lua.
     * @return Returns the number of values to be returned by the Lua function.
     */
    @Override
    public int invoke( LuaState luaState ) 
    {
        try
        {  
            Log.i( LeadboltCoronaClass.logTag, "SET SUB ID CALLED" );

            // Get the Corona activity
            CoronaActivity coronaActivity = null;
            if ( CoronaEnvironment.getCoronaActivity() != null )
            {
                coronaActivity = CoronaEnvironment.getCoronaActivity();
            }

            // The ad id
            String adId = null;
            // The sub id
            String subId = null;
            
            // Get the ad id
            if ( luaState.isString( 1 ) )
            {
                adId = luaState.toString( 1 );
            }
            else
            {
                Log.i( LeadboltCoronaClass.logTag, "leadbolt.setSubId( adId, subId ) adId expected, got " + luaState.typeName( 1 ) );
            }
            
            // Get the sub id
            if ( luaState.isString( 2 ) )
            {
                subId = luaState.toString( 2 );
            }
            else
            {
                Log.i( LeadboltCoronaClass.logTag, "leadbolt.setSubId( adId, subId ) subId expected, got " + luaState.typeName( 2 ) );
            }
                        
            // Set vars
            final String theAdId = adId;
            final String theSubId = subId;

            // Create a new runnable object to invoke our activity
            Runnable runnableActivity = new Runnable()
            {
                public void run()
                {
                    try
                    {
                        // Get the ad
                        AdController ad = LeadboltCoronaClass.overlayDict.get( theAdId );

                        // If the ad has been created
                        if ( ad != null )
                        {
                            Log.i( LeadboltCoronaClass.logTag, "SETTING SUB ID" );
                            // Set the sub id
                            ad.setSubId( theSubId );
                        }
                        else
                        {
                            Log.i( LeadboltCoronaClass.logTag, "not setting ad sub id, as it has not yet been created" );
                        }
                    }
                    catch( Exception ex )
                    {
                        Log.i( LeadboltCoronaClass.logTag,"GOT EXCEPTION, SEE BELOW" );
                        Log.i( LeadboltCoronaClass.logTag, ex.toString() );
                        ex.printStackTrace();
                    }         
                }
            };

            // Run the activity on the uiThread
            if ( coronaActivity != null )
            {
                coronaActivity.runOnUiThread( runnableActivity );
            }
        }
        catch( Exception ex )
        {
            // An exception will occur if given an invalid argument or no argument. Print the error.
            ex.printStackTrace();
        }
        
        return 0;
    }
}
